from setuptools import setup, find_packages

# Get version number
def getVersionNumber():
    with open("VERSION", 'r') as vfile:
        version = vfile.read().strip()
    return version
__version__ = getVersionNumber()

DESCRIPTION = "Tools for exploring reciprocal space"
LONG_DESCRIPTION = """
``reciprocalspaceship`` provides a ``pandas``-style interface for
analyzing and manipulating reflection data from crystallography 
experiments. Using this library, it is possible to interactively work 
with crystallographic data in Python, enabling easy integration  with 
modern scientific computing libraries. ``reciprocalspaceship`` is 
intended to support the rapid prototyping of new crystallographic methods 
and custom analyses while maintaining clear, reproducible, and performant 
code.

Features of this library include:

  - Crystallographically-aware ``pandas`` objects, datatypes, and syntax 
    that are familiar to Python users.
  - Convenient integration with `GEMMI <https://gemmi.readthedocs.io/en/latest/>`__ 
    to provide built-in methods and support for developing functions that 
    use space groups, unit cell parameters, and crystallographic symmetry 
    operations.
  - Support for reading and writing MTZ reflection files.
"""
PROJECT_URLS = {
    "Bug Tracker": "https://github.com/Hekstra-Lab/reciprocalspaceship/issues",
    "Documentation": "https://hekstra-lab.github.io/reciprocalspaceship/",
    "Source Code": "https://github.com/Hekstra-Lab/reciprocalspaceship",
}

setup(
    name='reciprocalspaceship',
    packages=find_packages(),
    version=__version__,
    license='MIT',
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    author='Kevin M. Dalton, Jack B. Greisman',
    author_email='kmdalton@g.harvard.edu, greisman@g.harvard.edu',
    url="https://hekstra-lab.github.io/reciprocalspaceship/",
    project_urls=PROJECT_URLS,
    install_requires=[
        "gemmi >= 0.4.0.post1",
        "pandas > 1.0",
        "numpy >  1.0",
        "scipy > 1.4",
    ],
    setup_requires=['pytest-runner'],
    tests_require=['pytest', 'pytest-cov', 'pytest-xdist'],
    entry_points={
        'console_scripts': [
            'rs.mtzdump=reciprocalspaceship.commandline.mtzdump:main',
        ]
    },
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: MIT License',
        'Topic :: Scientific/Engineering :: Chemistry',
        'Topic :: Scientific/Engineering :: Physics',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Programming Language :: Python',
    ],
)
